Class: Google::Shopping::Merchant::Reports::V1::PriceInsightsProductView
- Inherits:
-
Object
- Object
- Google::Shopping::Merchant::Reports::V1::PriceInsightsProductView
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/shopping/merchant/reports/v1/reports.rb
Overview
Fields available for query in price_insights_product_view table.
Price insights report.
Values are only set for fields requested explicitly in the request's search query.
Defined Under Namespace
Modules: Effectiveness
Instance Attribute Summary collapse
-
#brand ⇒ ::String
Brand of the product.
-
#category_l1 ⇒ ::String
Product category (1st level) in Google's product taxonomy.
-
#category_l2 ⇒ ::String
Product category (2nd level) in Google's product taxonomy.
-
#category_l3 ⇒ ::String
Product category (3rd level) in Google's product taxonomy.
-
#category_l4 ⇒ ::String
Product category (4th level) in Google's product taxonomy.
-
#category_l5 ⇒ ::String
Product category (5th level) in Google's product taxonomy.
-
#effectiveness ⇒ ::Google::Shopping::Merchant::Reports::V1::PriceInsightsProductView::Effectiveness
The predicted effectiveness of applying the price suggestion, bucketed.
-
#id ⇒ ::String
REST ID of the product, in the form of
channel~languageCode~feedLabel~offerId. -
#offer_id ⇒ ::String
Merchant-provided id of the product.
-
#predicted_clicks_change_fraction ⇒ ::Float
Predicted change in clicks as a fraction after introducing the suggested price compared to current active price.
-
#predicted_conversions_change_fraction ⇒ ::Float
Predicted change in conversions as a fraction after introducing the suggested price compared to current active price.
-
#predicted_impressions_change_fraction ⇒ ::Float
Predicted change in impressions as a fraction after introducing the suggested price compared to current active price.
-
#price ⇒ ::Google::Shopping::Type::Price
Current price of the product.
-
#product_type_l1 ⇒ ::String
Product type (1st level) in merchant's own product taxonomy.
-
#product_type_l2 ⇒ ::String
Product type (2nd level) in merchant's own product taxonomy.
-
#product_type_l3 ⇒ ::String
Product type (3rd level) in merchant's own product taxonomy.
-
#product_type_l4 ⇒ ::String
Product type (4th level) in merchant's own product taxonomy.
-
#product_type_l5 ⇒ ::String
Product type (5th level) in merchant's own product taxonomy.
-
#suggested_price ⇒ ::Google::Shopping::Type::Price
Latest suggested price for the product.
-
#title ⇒ ::String
Title of the product.
Instance Attribute Details
#brand ⇒ ::String
Returns Brand of the product.
763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 |
# File 'proto_docs/google/shopping/merchant/reports/v1/reports.rb', line 763 class PriceInsightsProductView include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Predicted effectiveness bucket. # # Effectiveness indicates which products would benefit most from price # changes. This rating takes into consideration the performance boost # predicted by adjusting the sale price and the difference between your # current price and the suggested price. Price suggestions with `HIGH` # effectiveness are predicted to drive the largest increase in performance. module Effectiveness # Effectiveness is unknown. EFFECTIVENESS_UNSPECIFIED = 0 # Effectiveness is low. LOW = 1 # Effectiveness is medium. MEDIUM = 2 # Effectiveness is high. HIGH = 3 end end |
#category_l1 ⇒ ::String
Returns Product category (1st level) in Google's product taxonomy.
763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 |
# File 'proto_docs/google/shopping/merchant/reports/v1/reports.rb', line 763 class PriceInsightsProductView include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Predicted effectiveness bucket. # # Effectiveness indicates which products would benefit most from price # changes. This rating takes into consideration the performance boost # predicted by adjusting the sale price and the difference between your # current price and the suggested price. Price suggestions with `HIGH` # effectiveness are predicted to drive the largest increase in performance. module Effectiveness # Effectiveness is unknown. EFFECTIVENESS_UNSPECIFIED = 0 # Effectiveness is low. LOW = 1 # Effectiveness is medium. MEDIUM = 2 # Effectiveness is high. HIGH = 3 end end |
#category_l2 ⇒ ::String
Returns Product category (2nd level) in Google's product taxonomy.
763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 |
# File 'proto_docs/google/shopping/merchant/reports/v1/reports.rb', line 763 class PriceInsightsProductView include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Predicted effectiveness bucket. # # Effectiveness indicates which products would benefit most from price # changes. This rating takes into consideration the performance boost # predicted by adjusting the sale price and the difference between your # current price and the suggested price. Price suggestions with `HIGH` # effectiveness are predicted to drive the largest increase in performance. module Effectiveness # Effectiveness is unknown. EFFECTIVENESS_UNSPECIFIED = 0 # Effectiveness is low. LOW = 1 # Effectiveness is medium. MEDIUM = 2 # Effectiveness is high. HIGH = 3 end end |
#category_l3 ⇒ ::String
Returns Product category (3rd level) in Google's product taxonomy.
763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 |
# File 'proto_docs/google/shopping/merchant/reports/v1/reports.rb', line 763 class PriceInsightsProductView include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Predicted effectiveness bucket. # # Effectiveness indicates which products would benefit most from price # changes. This rating takes into consideration the performance boost # predicted by adjusting the sale price and the difference between your # current price and the suggested price. Price suggestions with `HIGH` # effectiveness are predicted to drive the largest increase in performance. module Effectiveness # Effectiveness is unknown. EFFECTIVENESS_UNSPECIFIED = 0 # Effectiveness is low. LOW = 1 # Effectiveness is medium. MEDIUM = 2 # Effectiveness is high. HIGH = 3 end end |
#category_l4 ⇒ ::String
Returns Product category (4th level) in Google's product taxonomy.
763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 |
# File 'proto_docs/google/shopping/merchant/reports/v1/reports.rb', line 763 class PriceInsightsProductView include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Predicted effectiveness bucket. # # Effectiveness indicates which products would benefit most from price # changes. This rating takes into consideration the performance boost # predicted by adjusting the sale price and the difference between your # current price and the suggested price. Price suggestions with `HIGH` # effectiveness are predicted to drive the largest increase in performance. module Effectiveness # Effectiveness is unknown. EFFECTIVENESS_UNSPECIFIED = 0 # Effectiveness is low. LOW = 1 # Effectiveness is medium. MEDIUM = 2 # Effectiveness is high. HIGH = 3 end end |
#category_l5 ⇒ ::String
Returns Product category (5th level) in Google's product taxonomy.
763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 |
# File 'proto_docs/google/shopping/merchant/reports/v1/reports.rb', line 763 class PriceInsightsProductView include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Predicted effectiveness bucket. # # Effectiveness indicates which products would benefit most from price # changes. This rating takes into consideration the performance boost # predicted by adjusting the sale price and the difference between your # current price and the suggested price. Price suggestions with `HIGH` # effectiveness are predicted to drive the largest increase in performance. module Effectiveness # Effectiveness is unknown. EFFECTIVENESS_UNSPECIFIED = 0 # Effectiveness is low. LOW = 1 # Effectiveness is medium. MEDIUM = 2 # Effectiveness is high. HIGH = 3 end end |
#effectiveness ⇒ ::Google::Shopping::Merchant::Reports::V1::PriceInsightsProductView::Effectiveness
Returns The predicted effectiveness of applying the price suggestion, bucketed.
763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 |
# File 'proto_docs/google/shopping/merchant/reports/v1/reports.rb', line 763 class PriceInsightsProductView include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Predicted effectiveness bucket. # # Effectiveness indicates which products would benefit most from price # changes. This rating takes into consideration the performance boost # predicted by adjusting the sale price and the difference between your # current price and the suggested price. Price suggestions with `HIGH` # effectiveness are predicted to drive the largest increase in performance. module Effectiveness # Effectiveness is unknown. EFFECTIVENESS_UNSPECIFIED = 0 # Effectiveness is low. LOW = 1 # Effectiveness is medium. MEDIUM = 2 # Effectiveness is high. HIGH = 3 end end |
#id ⇒ ::String
Returns REST ID of the product, in the form of
channel~languageCode~feedLabel~offerId. Can be used to join data with the
product_view table.
Required in the SELECT clause.
763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 |
# File 'proto_docs/google/shopping/merchant/reports/v1/reports.rb', line 763 class PriceInsightsProductView include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Predicted effectiveness bucket. # # Effectiveness indicates which products would benefit most from price # changes. This rating takes into consideration the performance boost # predicted by adjusting the sale price and the difference between your # current price and the suggested price. Price suggestions with `HIGH` # effectiveness are predicted to drive the largest increase in performance. module Effectiveness # Effectiveness is unknown. EFFECTIVENESS_UNSPECIFIED = 0 # Effectiveness is low. LOW = 1 # Effectiveness is medium. MEDIUM = 2 # Effectiveness is high. HIGH = 3 end end |
#offer_id ⇒ ::String
Returns Merchant-provided id of the product.
763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 |
# File 'proto_docs/google/shopping/merchant/reports/v1/reports.rb', line 763 class PriceInsightsProductView include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Predicted effectiveness bucket. # # Effectiveness indicates which products would benefit most from price # changes. This rating takes into consideration the performance boost # predicted by adjusting the sale price and the difference between your # current price and the suggested price. Price suggestions with `HIGH` # effectiveness are predicted to drive the largest increase in performance. module Effectiveness # Effectiveness is unknown. EFFECTIVENESS_UNSPECIFIED = 0 # Effectiveness is low. LOW = 1 # Effectiveness is medium. MEDIUM = 2 # Effectiveness is high. HIGH = 3 end end |
#predicted_clicks_change_fraction ⇒ ::Float
Returns Predicted change in clicks as a fraction after introducing the suggested price compared to current active price. For example, 0.05 is a 5% predicted increase in clicks.
763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 |
# File 'proto_docs/google/shopping/merchant/reports/v1/reports.rb', line 763 class PriceInsightsProductView include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Predicted effectiveness bucket. # # Effectiveness indicates which products would benefit most from price # changes. This rating takes into consideration the performance boost # predicted by adjusting the sale price and the difference between your # current price and the suggested price. Price suggestions with `HIGH` # effectiveness are predicted to drive the largest increase in performance. module Effectiveness # Effectiveness is unknown. EFFECTIVENESS_UNSPECIFIED = 0 # Effectiveness is low. LOW = 1 # Effectiveness is medium. MEDIUM = 2 # Effectiveness is high. HIGH = 3 end end |
#predicted_conversions_change_fraction ⇒ ::Float
Returns Predicted change in conversions as a fraction after introducing the suggested price compared to current active price. For example, 0.05 is a 5% predicted increase in conversions).
763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 |
# File 'proto_docs/google/shopping/merchant/reports/v1/reports.rb', line 763 class PriceInsightsProductView include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Predicted effectiveness bucket. # # Effectiveness indicates which products would benefit most from price # changes. This rating takes into consideration the performance boost # predicted by adjusting the sale price and the difference between your # current price and the suggested price. Price suggestions with `HIGH` # effectiveness are predicted to drive the largest increase in performance. module Effectiveness # Effectiveness is unknown. EFFECTIVENESS_UNSPECIFIED = 0 # Effectiveness is low. LOW = 1 # Effectiveness is medium. MEDIUM = 2 # Effectiveness is high. HIGH = 3 end end |
#predicted_impressions_change_fraction ⇒ ::Float
Returns Predicted change in impressions as a fraction after introducing the suggested price compared to current active price. For example, 0.05 is a 5% predicted increase in impressions.
763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 |
# File 'proto_docs/google/shopping/merchant/reports/v1/reports.rb', line 763 class PriceInsightsProductView include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Predicted effectiveness bucket. # # Effectiveness indicates which products would benefit most from price # changes. This rating takes into consideration the performance boost # predicted by adjusting the sale price and the difference between your # current price and the suggested price. Price suggestions with `HIGH` # effectiveness are predicted to drive the largest increase in performance. module Effectiveness # Effectiveness is unknown. EFFECTIVENESS_UNSPECIFIED = 0 # Effectiveness is low. LOW = 1 # Effectiveness is medium. MEDIUM = 2 # Effectiveness is high. HIGH = 3 end end |
#price ⇒ ::Google::Shopping::Type::Price
Returns Current price of the product.
763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 |
# File 'proto_docs/google/shopping/merchant/reports/v1/reports.rb', line 763 class PriceInsightsProductView include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Predicted effectiveness bucket. # # Effectiveness indicates which products would benefit most from price # changes. This rating takes into consideration the performance boost # predicted by adjusting the sale price and the difference between your # current price and the suggested price. Price suggestions with `HIGH` # effectiveness are predicted to drive the largest increase in performance. module Effectiveness # Effectiveness is unknown. EFFECTIVENESS_UNSPECIFIED = 0 # Effectiveness is low. LOW = 1 # Effectiveness is medium. MEDIUM = 2 # Effectiveness is high. HIGH = 3 end end |
#product_type_l1 ⇒ ::String
Returns Product type (1st level) in merchant's own product taxonomy.
763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 |
# File 'proto_docs/google/shopping/merchant/reports/v1/reports.rb', line 763 class PriceInsightsProductView include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Predicted effectiveness bucket. # # Effectiveness indicates which products would benefit most from price # changes. This rating takes into consideration the performance boost # predicted by adjusting the sale price and the difference between your # current price and the suggested price. Price suggestions with `HIGH` # effectiveness are predicted to drive the largest increase in performance. module Effectiveness # Effectiveness is unknown. EFFECTIVENESS_UNSPECIFIED = 0 # Effectiveness is low. LOW = 1 # Effectiveness is medium. MEDIUM = 2 # Effectiveness is high. HIGH = 3 end end |
#product_type_l2 ⇒ ::String
Returns Product type (2nd level) in merchant's own product taxonomy.
763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 |
# File 'proto_docs/google/shopping/merchant/reports/v1/reports.rb', line 763 class PriceInsightsProductView include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Predicted effectiveness bucket. # # Effectiveness indicates which products would benefit most from price # changes. This rating takes into consideration the performance boost # predicted by adjusting the sale price and the difference between your # current price and the suggested price. Price suggestions with `HIGH` # effectiveness are predicted to drive the largest increase in performance. module Effectiveness # Effectiveness is unknown. EFFECTIVENESS_UNSPECIFIED = 0 # Effectiveness is low. LOW = 1 # Effectiveness is medium. MEDIUM = 2 # Effectiveness is high. HIGH = 3 end end |
#product_type_l3 ⇒ ::String
Returns Product type (3rd level) in merchant's own product taxonomy.
763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 |
# File 'proto_docs/google/shopping/merchant/reports/v1/reports.rb', line 763 class PriceInsightsProductView include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Predicted effectiveness bucket. # # Effectiveness indicates which products would benefit most from price # changes. This rating takes into consideration the performance boost # predicted by adjusting the sale price and the difference between your # current price and the suggested price. Price suggestions with `HIGH` # effectiveness are predicted to drive the largest increase in performance. module Effectiveness # Effectiveness is unknown. EFFECTIVENESS_UNSPECIFIED = 0 # Effectiveness is low. LOW = 1 # Effectiveness is medium. MEDIUM = 2 # Effectiveness is high. HIGH = 3 end end |
#product_type_l4 ⇒ ::String
Returns Product type (4th level) in merchant's own product taxonomy.
763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 |
# File 'proto_docs/google/shopping/merchant/reports/v1/reports.rb', line 763 class PriceInsightsProductView include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Predicted effectiveness bucket. # # Effectiveness indicates which products would benefit most from price # changes. This rating takes into consideration the performance boost # predicted by adjusting the sale price and the difference between your # current price and the suggested price. Price suggestions with `HIGH` # effectiveness are predicted to drive the largest increase in performance. module Effectiveness # Effectiveness is unknown. EFFECTIVENESS_UNSPECIFIED = 0 # Effectiveness is low. LOW = 1 # Effectiveness is medium. MEDIUM = 2 # Effectiveness is high. HIGH = 3 end end |
#product_type_l5 ⇒ ::String
Returns Product type (5th level) in merchant's own product taxonomy.
763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 |
# File 'proto_docs/google/shopping/merchant/reports/v1/reports.rb', line 763 class PriceInsightsProductView include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Predicted effectiveness bucket. # # Effectiveness indicates which products would benefit most from price # changes. This rating takes into consideration the performance boost # predicted by adjusting the sale price and the difference between your # current price and the suggested price. Price suggestions with `HIGH` # effectiveness are predicted to drive the largest increase in performance. module Effectiveness # Effectiveness is unknown. EFFECTIVENESS_UNSPECIFIED = 0 # Effectiveness is low. LOW = 1 # Effectiveness is medium. MEDIUM = 2 # Effectiveness is high. HIGH = 3 end end |
#suggested_price ⇒ ::Google::Shopping::Type::Price
Returns Latest suggested price for the product.
763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 |
# File 'proto_docs/google/shopping/merchant/reports/v1/reports.rb', line 763 class PriceInsightsProductView include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Predicted effectiveness bucket. # # Effectiveness indicates which products would benefit most from price # changes. This rating takes into consideration the performance boost # predicted by adjusting the sale price and the difference between your # current price and the suggested price. Price suggestions with `HIGH` # effectiveness are predicted to drive the largest increase in performance. module Effectiveness # Effectiveness is unknown. EFFECTIVENESS_UNSPECIFIED = 0 # Effectiveness is low. LOW = 1 # Effectiveness is medium. MEDIUM = 2 # Effectiveness is high. HIGH = 3 end end |
#title ⇒ ::String
Returns Title of the product.
763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 |
# File 'proto_docs/google/shopping/merchant/reports/v1/reports.rb', line 763 class PriceInsightsProductView include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Predicted effectiveness bucket. # # Effectiveness indicates which products would benefit most from price # changes. This rating takes into consideration the performance boost # predicted by adjusting the sale price and the difference between your # current price and the suggested price. Price suggestions with `HIGH` # effectiveness are predicted to drive the largest increase in performance. module Effectiveness # Effectiveness is unknown. EFFECTIVENESS_UNSPECIFIED = 0 # Effectiveness is low. LOW = 1 # Effectiveness is medium. MEDIUM = 2 # Effectiveness is high. HIGH = 3 end end |